==> haskell-rio-0.1.3.0-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-rio.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: rio
version: 0.1.3.0
id: rio-0.1.3.0-BROjzlaXQdE3LA1zgvwkSb
key: rio-0.1.3.0-BROjzlaXQdE3LA1zgvwkSb
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/commercialhaskell/rio#readme
synopsis: A standard library for Haskell
description:
    See README and Haddocks at <https://www.stackage.org/package/rio>
category: Control
abi: ba36f21306d1aec8294aadcdcd4fcb9c
exposed: True
exposed-modules:
    RIO RIO.ByteString RIO.ByteString.Lazy RIO.ByteString.Lazy.Partial
    RIO.ByteString.Partial RIO.Char RIO.Char.Partial RIO.Directory
    RIO.FilePath RIO.HashMap RIO.HashMap.Partial RIO.HashSet RIO.List
    RIO.List.Partial RIO.Map RIO.Map.Partial RIO.Map.Unchecked
    RIO.Prelude.Simple RIO.Process RIO.Seq RIO.Set RIO.Set.Partial
    RIO.Set.Unchecked RIO.Text RIO.Text.Lazy RIO.Text.Lazy.Partial
    RIO.Text.Partial RIO.Time RIO.Vector RIO.Vector.Boxed
    RIO.Vector.Boxed.Partial RIO.Vector.Boxed.Unsafe RIO.Vector.Partial
    RIO.Vector.Storable RIO.Vector.Storable.Partial
    RIO.Vector.Storable.Unsafe RIO.Vector.Unboxed
    RIO.Vector.Unboxed.Partial RIO.Vector.Unboxed.Unsafe
    RIO.Vector.Unsafe
hidden-modules: RIO.Prelude.Display RIO.Prelude.Extra
                RIO.Prelude.IO RIO.Prelude.Lens RIO.Prelude.Logger
                RIO.Prelude.Reexports RIO.Prelude.Renames RIO.Prelude.RIO
                RIO.Prelude.Text RIO.Prelude.Trace RIO.Prelude.URef
import-dirs: /usr/lib/ghc-8.4.3/site-local/rio-0.1.3.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/rio-0.1.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/rio-0.1.3.0
hs-libraries: HSrio-0.1.3.0-BROjzlaXQdE3LA1zgvwkSb
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    deepseq-1.4.3.0 directory-1.3.1.5
    exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf filepath-1.4.2
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    microlens-0.4.9.1-Il1wVteoTNOAmlNI3I8KNh mtl-2.2.2
    primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc process-1.6.3.0
    text-1.2.3.0 time-1.8.0.2
    typed-process-0.2.2.0-4agRql4JOiA8oVrUGf4E7s
    unliftio-0.2.7.0-AVCNN2qxwsPAnMqSXwNxxs
    unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq unix-2.7.2.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf=7910067871295cb7f4f6699a852863a6
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             microlens-0.4.9.1-Il1wVteoTNOAmlNI3I8KNh=ea4e8465edaf940bc6b809afec7d8a0c
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc=0a8d9e3ca28de3a4ac62e5f0044fa23c
             process-1.6.3.0=b58285e21ceee9f67d7be28ddb8b2627
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             typed-process-0.2.2.0-4agRql4JOiA8oVrUGf4E7s=81e840f3b05d4824020a87ad5f9e62d7
             unliftio-0.2.7.0-AVCNN2qxwsPAnMqSXwNxxs=53bd061d72502e5ed7f709e68c6e62fb
             unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu=5b052eced98346d45f3db03378f2841d
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
haddock-interfaces: /usr/share/doc/haskell-rio/html/rio.haddock
haddock-html: /usr/share/doc/haskell-rio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rio-0.1.3.0-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-rio.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: rio
version: 0.1.3.0
id: rio-0.1.3.0-9NSinkDXflFCcTsPydXWWR
key: rio-0.1.3.0-9NSinkDXflFCcTsPydXWWR
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/commercialhaskell/rio#readme
synopsis: A standard library for Haskell
description:
    See README and Haddocks at <https://www.stackage.org/package/rio>
category: Control
abi: d898a8025c57e42b755ab8ce9bbc0622
exposed: True
exposed-modules:
    RIO RIO.ByteString RIO.ByteString.Lazy RIO.ByteString.Lazy.Partial
    RIO.ByteString.Partial RIO.Char RIO.Char.Partial RIO.Directory
    RIO.FilePath RIO.HashMap RIO.HashMap.Partial RIO.HashSet RIO.List
    RIO.List.Partial RIO.Map RIO.Map.Partial RIO.Map.Unchecked
    RIO.Prelude.Simple RIO.Process RIO.Seq RIO.Set RIO.Set.Partial
    RIO.Set.Unchecked RIO.Text RIO.Text.Lazy RIO.Text.Lazy.Partial
    RIO.Text.Partial RIO.Time RIO.Vector RIO.Vector.Boxed
    RIO.Vector.Boxed.Partial RIO.Vector.Boxed.Unsafe RIO.Vector.Partial
    RIO.Vector.Storable RIO.Vector.Storable.Partial
    RIO.Vector.Storable.Unsafe RIO.Vector.Unboxed
    RIO.Vector.Unboxed.Partial RIO.Vector.Unboxed.Unsafe
    RIO.Vector.Unsafe
hidden-modules: RIO.Prelude.Display RIO.Prelude.Extra
                RIO.Prelude.IO RIO.Prelude.Lens RIO.Prelude.Logger
                RIO.Prelude.Reexports RIO.Prelude.Renames RIO.Prelude.RIO
                RIO.Prelude.Text RIO.Prelude.Trace RIO.Prelude.URef
import-dirs: /usr/lib/ghc-8.4.3/site-local/rio-0.1.3.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/rio-0.1.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/rio-0.1.3.0
hs-libraries: HSrio-0.1.3.0-9NSinkDXflFCcTsPydXWWR
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    deepseq-1.4.3.0 directory-1.3.1.5
    exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf filepath-1.4.2
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    microlens-0.4.9.1-Il1wVteoTNOAmlNI3I8KNh mtl-2.2.2
    primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc process-1.6.3.0
    text-1.2.3.0 time-1.8.0.2
    typed-process-0.2.2.0-CIEqKnlg80XIOAf5Qe2Xno
    unliftio-0.2.7.0-A0bfAAmhFhQH8zoiBdg2SS
    unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq unix-2.7.2.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf=7910067871295cb7f4f6699a852863a6
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             microlens-0.4.9.1-Il1wVteoTNOAmlNI3I8KNh=ea4e8465edaf940bc6b809afec7d8a0c
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc=0a8d9e3ca28de3a4ac62e5f0044fa23c
             process-1.6.3.0=b58285e21ceee9f67d7be28ddb8b2627
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             typed-process-0.2.2.0-CIEqKnlg80XIOAf5Qe2Xno=20126189374dfcc9cc2a400d8ee33186
             unliftio-0.2.7.0-A0bfAAmhFhQH8zoiBdg2SS=199e72d45bee72cb4a58e3a9bd24c9a8
             unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu=5b052eced98346d45f3db03378f2841d
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
haddock-interfaces: /usr/share/doc/haskell-rio/html/rio.haddock
haddock-html: /usr/share/doc/haskell-rio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
